@@ -317,7 +317,10 @@ SKKInstance::process_key_event (const KeyEvent &key)
     // ignore modifier keys
     if (key.code == SCIM_KEY_Shift_L || key.code == SCIM_KEY_Shift_R ||
         key.code == SCIM_KEY_Control_L || key.code == SCIM_KEY_Control_R ||
-        key.code == SCIM_KEY_Alt_L || key.code == SCIM_KEY_Alt_R)
+        key.code == SCIM_KEY_Alt_L || key.code == SCIM_KEY_Alt_R ||
+        key.code == SCIM_KEY_Meta_L || key.code == SCIM_KEY_Meta_R ||
+        key.code == SCIM_KEY_Caps_Lock || key.code == SCIM_KEY_Shift_Lock
+        )
         return false;
 
     KeyEvent k(key.code, key.mask);
@@ -334,15 +337,14 @@ SKKInstance::process_key_event (const KeyEvent &key)
 
     WideString preedit;
     m_skkcore.get_preedit_string(preedit);
+    update_preedit_string(preedit);
     if (!preedit.empty()) {
-        update_preedit_string(preedit);
+        update_preedit_caret(m_skkcore.caret_pos());
         show_preedit_string();
     } else {
         hide_preedit_string();
     }
 
-    update_preedit_caret(m_skkcore.caret_pos());
-
     if (m_skkcore.show_lookup_table()) {
         m_lookup_table.set_page_size(m_default_page_size);
         update_lookup_table(m_lookup_table);
@@ -415,6 +417,7 @@ SKKInstance::select_candidate (unsigned int index)
         commit_string(m_skkcore.get_commit_string());
         m_skkcore.clear_commit();
     }
+    update_preedit_string(WideString());
     hide_lookup_table();
     hide_preedit_string();
 }
@@ -469,15 +472,14 @@ SKKInstance::focus_in ()
     install_properties();
 
     m_skkcore.get_preedit_string(preedit);
+    update_preedit_string(preedit);
     if (!preedit.empty()) {
-        update_preedit_string(preedit);
+        update_preedit_caret(m_skkcore.caret_pos());
         show_preedit_string();
     } else {
         hide_preedit_string();
     }
 
-    update_preedit_caret(m_skkcore.caret_pos());
-
     if (m_skkcore.show_lookup_table()) {
         update_lookup_table(m_lookup_table);
         show_lookup_table();
